import { Query } from '@/api/webApi'
import { CommonValue, CommonData, CommonTableColumn } from '~/common'

const tableColumnsMap: {
  [tableName: string]: ({
    columnLabel: string
    columnName: string
  } & CommonData)[]
} = {
  flightContainer: [
    { columnLabel: '集装器编号', columnName: 'C0', width: '120px' },
    { columnLabel: '运单数', columnName: 'C1', width: '60px', needCount: 1 },
    { columnLabel: '件数', columnName: 'C2', width: '60px', needCount: 1 },
    { columnLabel: '理货', columnName: 'C3' },
    { columnLabel: '拉下', columnName: 'C4' },
    { columnLabel: '待运区', columnName: 'C5' },
    { columnLabel: '货站交接', columnName: 'C6' },
    { columnLabel: '机下交接', columnName: 'C7' },
    { columnLabel: '装机', columnName: 'C8' },
  ],
  flightWaybill: [
    { columnLabel: '运单号', columnName: 'C0', width: '120px' },
    { columnLabel: '集装器数量', columnName: 'C1', needCount: 1 },
    { columnLabel: '品名', columnName: 'C2' },
    { columnLabel: '特货信息', columnName: 'C3' },
    { columnLabel: '货物件数', columnName: 'C4', needCount: 1 },
    { columnLabel: '拉下件数', columnName: 'C5', needCount: 1 },
    { columnLabel: '退运件数', columnName: 'C6', needCount: 1 },
    { columnLabel: '最新节点', columnName: 'C7' },
    { columnLabel: '最新位置', columnName: 'C8' },
    { columnLabel: '处理结果', columnName: 'C9' },
    { columnLabel: '处理时间', columnName: 'C10', width: '130px' },
    { columnLabel: '中转进航班号', columnName: 'C11' },
    { columnLabel: '中转航班降落时间', columnName: 'C12', width: '130px' },
    { columnLabel: '装载序号', columnName: 'C13' },
  ],
}
const simulateTableDataMap: {
  [tableName: string]: CommonData[]
} = {
  flightContainer: [
    {
      C0: 'DOU29800001',
      C1: '5',
      C2: '50',
      C3: 'C24  11:01',
      C4: 'F24  12:05',
      C5: 'D32  11:25',
      C6: 'E24  11:40',
      C7: 'F24  12:01',
      C8: 'G32  12:25',
    },
    {
      C0: 'DOU29800001',
      C1: '5',
      C2: '50',
      C3: 'C24  11:01',
      C4: 'F24  12:05',
      C5: 'D32  11:25',
      C6: 'E24  11:40',
      C7: 'F24  12:01',
      C8: 'G32  12:25',
    },
  ],
  flightWaybill: [
    {
      C0: '32535234445',
      C1: '5',
      C2: '手机、充电器',
      C3: '特',
      C4: '5',
      C5: '2',
      C6: '2',
      C7: '待运区',
      C8: 'A13',
      C9: '通过',
      C10: '2022/9/10 10:01',
      C11: 'ZH5466',
      C12: '2022/9/10 16:01',
      C13: '3',
    },
    {
      C0: '32535234445',
      C1: '5',
      C2: '手机、充电器',
      C3: '特',
      C4: '5',
      C5: '2',
      C6: '2',
      C7: '待运区',
      C8: 'A13',
      C9: '通过',
      C10: '2022/9/10 10:01',
      C11: 'ZH5466',
      C12: '2022/9/10 16:01',
      C13: '3',
    },
    {
      C0: '32535234445',
      C1: '5',
      C2: '手机、充电器',
      C3: '特',
      C4: '5',
      C5: '2',
      C6: '2',
      C7: '待运区',
      C8: 'A13',
      C9: '未通过',
      C10: '2022/9/10 10:01',
      C11: 'ZH5466',
      C12: '2022/9/10 16:01',
      C13: '3',
    },
  ],
}

export default function useTable(
  tableName: string,
  dataContent?: CommonValue[]
) {
  const tableColumns = ref<CommonTableColumn[]>([])
  const tableData = ref<CommonData[]>([])
  const getTableColumns = () => {
    tableColumns.value = tableColumnsMap[tableName].map(column => ({
      columnDescribe: '',
      dataType: '',
      listqueryTemplateID: null,
      needCount: null,
      needFilters: null,
      needGroup: null,
      needSearch: null,
      needShow: 1,
      needSort: null,
      orderNumber: null,
      queryTemplateColumnSetID: null,
      queryTemplateID: null,
      align: 'center',
      ...column,
    }))
  }
  const getTableData = async () => {
    try {
      const {
        code,
        returnData: { columnSet, listValues },
        message,
      } = await Query<CommonData>({
        id: DATACONTENT_ID[tableName],
        dataContent,
      })
      if (Number(code) !== 0) {
        throw new Error(message || '失败')
      }
      tableData.value = listValues
    } catch (error) {
      console.error(error)
    }
  }
  const getSimulateTableData = () => {
    tableData.value = simulateTableDataMap[tableName]
  }

  onMounted(() => {
    if (tableColumnsMap[tableName]) {
      getTableColumns()
      // getTableData()
      getSimulateTableData()
    }
  })

  return {
    tableColumns,
    tableData,
  }
}
